@@ -51,7 +51,7 @@ asWKTSpatialPoints = function(x, digits = getOption("digits")) {
 		print(x@coords)
 	pst <- paste(strwrap(paste(
 		"Coordinate Reference System (CRS) arguments:", 
-		proj4string(x))), collapse="\n")
+		slot(slot(x, "proj4string"), "projargs"))), collapse="\n")
 	cat(pst, "\n")
 }
 setMethod("show", "SpatialPoints", function(object) print.SpatialPoints(object))
@@ -80,8 +80,9 @@ setAs("SpatialPoints", "data.frame", function(from) as.data.frame(from))
 row.names.SpatialPoints <- function(x) {
     ret = dimnames(slot(x, "coords"))[[1]]
 	if (is.null(ret))
-		ret = seq_len(nrow(slot(x, "coords")))
-	ret
+		seq_len(nrow(slot(x, "coords")))
+	else 
+		ret
 }
 
 "row.names<-.SpatialPoints" <- function(x, value) {
